@@ -48,13 +48,13 @@ function validateForm( form ) {
     }
   }
   if ( errors.length ) {
-    alert( errors.join( "\n" ) );
-    return( false );
+    alert(errors.join("\n"));
+    return false;
   }
-  return( true );
+  return true;
 }
 
-function submitForm( form ) {
+function submitForm(form) {
   form.elements['newZone[AlarmRGB]'].value = (form.newAlarmRgbR.value<<16)|(form.newAlarmRgbG.value<<8)|form.newAlarmRgbB.value;
   form.elements['newZone[NumCoords]'].value = zone['Points'].length;
   form.elements['newZone[Coords]'].value = getCoordString();
@@ -175,14 +175,16 @@ function applyPreset() {
   }
 }
 
-function toPixels( field, maxValue ) {
-  if ( field.value != '' )
+function toPixels(field, maxValue) {
+  if ( field.value != '' ) {
     field.value = Math.round((field.value*maxValue)/100);
+  }
 }
 
-function toPercent( field, maxValue ) {
-  if ( field.value != '' )
+function toPercent(field, maxValue) {
+  if ( field.value != '' ) {
     field.value = Math.round((100*100*field.value)/maxValue)/100;
+  }
 }
 
 function applyZoneUnits() {
@@ -191,68 +193,80 @@ function applyZoneUnits() {
   var form = document.zoneForm;
   if ( form.elements['newZone[Units]'].value == 'Pixels' ) {
     form.elements['newZone[TempArea]'].value = area;
-    toPixels( form.elements['newZone[MinAlarmPixels]'], area );
-    toPixels( form.elements['newZone[MaxAlarmPixels]'], area );
-    toPixels( form.elements['newZone[MinFilterPixels]'], area );
-    toPixels( form.elements['newZone[MaxFilterPixels]'], area );
-    toPixels( form.elements['newZone[MinBlobPixels]'], area );
-    toPixels( form.elements['newZone[MaxBlobPixels]'], area );
+    toPixels(form.elements['newZone[MinAlarmPixels]'], area);
+    toPixels(form.elements['newZone[MaxAlarmPixels]'], area);
+    toPixels(form.elements['newZone[MinFilterPixels]'], area);
+    toPixels(form.elements['newZone[MaxFilterPixels]'], area);
+    toPixels(form.elements['newZone[MinBlobPixels]'], area);
+    toPixels(form.elements['newZone[MaxBlobPixels]'], area);
   } else {
-    form.elements['newZone[TempArea]'].value = Math.round( area/monitorArea * 100 );
-    toPercent( form.elements['newZone[MinAlarmPixels]'], area );
-    toPercent( form.elements['newZone[MaxAlarmPixels]'], area );
-    toPercent( form.elements['newZone[MinFilterPixels]'], area );
-    toPercent( form.elements['newZone[MaxFilterPixels]'], area );
-    toPercent( form.elements['newZone[MinBlobPixels]'], area );
-    toPercent( form.elements['newZone[MaxBlobPixels]'], area );
+    form.elements['newZone[TempArea]'].value = Math.round(area/monitorArea * 100);
+    toPercent(form.elements['newZone[MinAlarmPixels]'], area);
+    toPercent(form.elements['newZone[MaxAlarmPixels]'], area);
+    toPercent(form.elements['newZone[MinFilterPixels]'], area);
+    toPercent(form.elements['newZone[MaxFilterPixels]'], area);
+    toPercent(form.elements['newZone[MinBlobPixels]'], area);
+    toPercent(form.elements['newZone[MaxBlobPixels]'], area);
   }
 }
 
-function limitRange( field, minValue, maxValue ) {
-  if ( field.value != '' )
-    field.value = constrainValue( parseInt(field.value), parseInt(minValue), parseInt(maxValue) );
+function limitRange(field, minValue, maxValue) {
+  if ( field.value != '' ) {
+    field.value = constrainValue(
+        parseInt(field.value),
+        parseInt(minValue),
+        parseInt(maxValue)
+    );
+  }
 }
 
-function limitFilter( field ) {
+function limitRangeToUnsignedByte(field) {
+  if ( field.value != '' ) {
+    field.value = constrainValue(parseInt(field.value), 0, 255);
+  }
+}
+
+function limitFilter(field) {
   field.value = (Math.floor((field.value-1)/2)*2) + 1;
   field.value = constrainValue(parseInt(field.value), 3, 15);
 }
 
-function limitArea( field ) {
+function limitArea(field) {
   var minValue = 0;
   var maxValue = zone.Area;
-  if ( document.zoneForm.elements['newZone[Units]'].value == "Percent" ) {
+  if ( document.zoneForm.elements['newZone[Units]'].value == 'Percent' ) {
     maxValue = 100;
   }
-  limitRange( field, minValue, maxValue );
+  limitRange(field, minValue, maxValue);
 }
 
-function highlightOn( index ) {
-  $('row'+index).addClass( 'highlight' );
-  $('point'+index).addClass( 'highlight' );
+function highlightOn(index) {
+  $('row'+index).addClass('highlight');
+  $('point'+index).addClass('highlight');
 }
 
-function highlightOff( index ) {
-  $('row'+index).removeClass( 'highlight' );
-  $('point'+index).removeClass( 'highlight' );
+function highlightOff(index) {
+  $('row'+index).removeClass('highlight');
+  $('point'+index).removeClass('highlight');
 }
 
-function setActivePoint( index ) {
-  highlightOff( index );
-  $('row'+index).addClass( 'active' );
-  $('point'+index).addClass( 'active' );
+function setActivePoint(index) {
+  highlightOff(index);
+  $('row'+index).addClass('active');
+  $('point'+index).addClass('active');
 }
 
-function unsetActivePoint( index ) {
-  $('row'+index).removeClass( 'active' );
-  $('point'+index).removeClass( 'active' );
+function unsetActivePoint(index) {
+  $('row'+index).removeClass('active');
+  $('point'+index).removeClass('active');
 }
 
 function getCoordString() {
   var coords = new Array();
-  for ( var i = 0; i < zone['Points'].length; i++ )
+  for ( var i = 0; i < zone['Points'].length; i++ ) {
     coords[coords.length] = zone['Points'][i].x+','+zone['Points'][i].y;
-  return( coords.join( " " ) );
+  }
+  return coords.join(' ');
 }
 
 function updateZoneImage() {
@@ -263,17 +277,17 @@ function updateZoneImage() {
     var Point = SVG.createSVGPoint();
     Point.x = zone['Points'][i].x;
     Point.y = zone['Points'][i].y;
-    Poly.points.appendItem( Point );
+    Poly.points.appendItem(Point);
   }
 }
 
-function fixActivePoint( index ) {
-  updateActivePoint( index );
-  unsetActivePoint( index );
+function fixActivePoint(index) {
+  updateActivePoint(index);
+  unsetActivePoint(index);
   updateZoneImage();
 }
 
-function constrainValue( value, loVal, hiVal ) {
+function constrainValue(value, loVal, hiVal) {
   if ( value < loVal ) {
     return loVal;
   }
@@ -283,10 +297,10 @@ function constrainValue( value, loVal, hiVal ) {
   return value;
 }
 
-function updateActivePoint( index ) {
+function updateActivePoint(index) {
   var point = $('point'+index);
-  var x = constrainValue( point.getStyle( 'left' ).toInt(), 0, maxX );
-  var y = constrainValue( point.getStyle( 'top' ).toInt(), 0, maxY );
+  var x = constrainValue(point.getStyle('left').toInt(), 0, maxX);
+  var y = constrainValue(point.getStyle('top').toInt(), 0, maxY);
 
   $('newZone[Points]['+index+'][x]').value = x;
   $('newZone[Points]['+index+'][y]').value = y;
@@ -298,33 +312,35 @@ function updateActivePoint( index ) {
   updateArea();
 }
 
-function addPoint( index ) {
+function addPoint(index) {
   var nextIndex = index+1;
-  if ( index >= (zone['Points'].length-1) )
+  if ( index >= (zone['Points'].length-1) ) {
     nextIndex = 0;
+  }
   var newX = parseInt(Math.round((zone['Points'][index]['x']+zone['Points'][nextIndex]['x'])/2));
   var newY = parseInt(Math.round((zone['Points'][index]['y']+zone['Points'][nextIndex]['y'])/2));
-  if ( nextIndex == 0 )
-    zone['Points'][zone['Points'].length] = { 'x': newX, 'y': newY };
-  else
-    zone['Points'].splice( nextIndex, 0, { 'x': newX, 'y': newY } );
+  if ( nextIndex == 0 ) {
+    zone['Points'][zone['Points'].length] = {'x': newX, 'y': newY};
+  } else {
+    zone['Points'].splice( nextIndex, 0, {'x': newX, 'y': newY} );
+  }
   drawZonePoints();
   // drawZonePoints calls updateZoneImage
   //updateZoneImage();
   //setActivePoint( nextIndex );
 }
 
-function delPoint( index ) {
-  zone['Points'].splice( index, 1 );
+function delPoint(index) {
+  zone['Points'].splice(index, 1);
   drawZonePoints();
 }
 
-function limitPointValue( point, loVal, hiVal ) {
+function limitPointValue(point, loVal, hiVal) {
   point.value = constrainValue(point.value, loVal, hiVal);
 }
 
 function updateArea( ) {
-  area = Polygon_calcArea( zone['Points'] );
+  area = Polygon_calcArea(zone['Points']);
   zone.Area = area;
   var form = $('zoneForm');
   form.elements['newZone[Area]'].value = area;
@@ -333,89 +349,125 @@ function updateArea( ) {
   } else if ( form.elements['newZone[Units]'].value == 'Pixels' ) {
     form.elements['newZone[TempArea]'].value = area;
   } else {
-    alert("Unknown units: " + form.elements['newZone[Units]'].value );
+    alert("Unknown units: " + form.elements['newZone[Units]'].value);
   }
 }
 
-function updateX( index ) {
-  limitPointValue( $('newZone[Points]['+index+'][x]'), 0, maxX );
+function updateX(index) {
+  limitPointValue($('newZone[Points]['+index+'][x]'), 0, maxX);
 
   var point = $('point'+index);
   var x = $('newZone[Points]['+index+'][x]').get('value');
 
-  point.setStyle( 'left', x+'px' );
+  point.setStyle('left', x+'px');
   zone['Points'][index].x = x;
   var Point = $('zonePoly').points.getItem(index);
   Point.x = x;
+  updateArea();
 }
 
-function updateY( index ) {
-  limitPointValue( $('newZone[Points]['+index+'][y]'), 0, maxY );
+function updateY(index) {
+  limitPointValue($('newZone[Points]['+index+'][y]'), 0, maxY);
 
   var point = $('point'+index);
   var y = $('newZone[Points]['+index+'][y]').get('value');
 
-  point.setStyle( 'top', y+'px' );
+  point.setStyle('top', y+'px');
   zone['Points'][index].y = y;
   var Point = $('zonePoly').points.getItem(index);
   Point.y = y;
+  updateArea();
 }
 
-function saveChanges( element ) {
+function saveChanges(element) {
   var form = element.form;
-  if ( validateForm( form ) ) {
-    submitForm( form );
+  if ( validateForm(form) ) {
+    submitForm(form);
     if ( form.elements['newZone[Type]'].value == 'Privacy' ) {
       alert( 'Capture process for this monitor will be restarted for the Privacy zone changes to take effect.' );
     }
-    return( true );
+    return true;
   }
-  return( false );
+  return false;
 }
 
 function drawZonePoints() {
-  $('imageFrame').getElements( 'div.zonePoint' ).each( function( element ) { element.destroy(); } );
+  $('imageFrame').getElements('div.zonePoint').each(
+      function(element) {
+        element.destroy();
+      });
   for ( var i = 0; i < zone['Points'].length; i++ ) {
-    var div = new Element( 'div', { 'id': 'point'+i, 'class': 'zonePoint', 'title': 'Point '+(i+1), 'styles': { 'left': zone['Points'][i].x, 'top': zone['Points'][i].y } } );
-    div.addEvent( 'mouseover', highlightOn.pass( i ) );
-    div.addEvent( 'mouseout', highlightOff.pass( i ) );
-    div.inject( $('imageFrame') );
-    div.makeDraggable( { 
-        'container': $('imageFrame'),
-        'onStart': setActivePoint.pass( i ), 
-        'onComplete': fixActivePoint.pass( i ),
-        'onDrag': updateActivePoint.pass( i )
-        } );
+    var div = new Element('div', {
+      'id': 'point'+i,
+      'class': 'zonePoint',
+      'title': 'Point '+(i+1),
+      'styles': {
+        'left': zone['Points'][i].x,
+        'top': zone['Points'][i].y
+      }
+    });
+    div.addEvent('mouseover', highlightOn.pass(i));
+    div.addEvent('mouseout', highlightOff.pass(i));
+    div.inject($('imageFrame'));
+    div.makeDraggable( {
+      'container': $('imageFrame'),
+      'onStart': setActivePoint.pass(i),
+      'onComplete': fixActivePoint.pass(i),
+      'onDrag': updateActivePoint.pass(i)
+    } );
   }
 
-  var tables = $('zonePoints').getElements( 'table' );
-  tables.each( function( table ) { table.getElement( 'tbody' ).empty(); } );
+  var tables = $('zonePoints').getElement('table').getElements('table');
+  tables.each( function(table) {
+    table.getElement('tbody').empty();
+  } );
+
   for ( var i = 0; i < zone['Points'].length; i++ ) {
-    var row = new Element( 'tr', { 'id': 'row'+i } );
-    row.addEvents( { 'mouseover': highlightOn.pass( i ), 'mouseout': highlightOff.pass( i ) } );
-    var cell = new Element( 'td' );
-    cell.set( 'text', i+1 );
-    cell.inject( row );
+    var row;
+    row = new Element('tr', {'id': 'row'+i});
+    row.addEvents({'mouseover': highlightOn.pass(i), 'mouseout': highlightOff.pass(i)});
+    var cell = new Element('td');
+    cell.set('text', i+1);
+    cell.inject(row);
 
-    cell = new Element( 'td' );
-    var input = new Element( 'input', { 'id': 'newZone[Points]['+i+'][x]', 'name': 'newZone[Points]['+i+'][x]', 'value': zone['Points'][i].x, 'size': 5 } );
-    input.addEvent( 'input', updateX.pass( i ) );
-    input.inject( cell );
-    cell.inject( row );
+    cell = new Element('td');
+    var input = new Element('input', {
+      'id': 'newZone[Points]['+i+'][x]',
+      'name': 'newZone[Points]['+i+'][x]',
+      'value': zone['Points'][i].x,
+      'size': 5
+    });
+    input.addEvent('input', updateX.pass(i));
+    input.inject(cell);
+    cell.inject(row);
 
-    cell = new Element( 'td' );
-    input = new Element( 'input', { 'id': 'newZone[Points]['+i+'][y]', 'name': 'newZone[Points]['+i+'][y]', 'value': zone['Points'][i].y, 'size': 5 } );
-    input.addEvent( 'input', updateY.pass( i ) );
-    input.inject( cell );
-    cell.inject( row );
+    cell = new Element('td');
+    input = new Element('input', {
+      'id': 'newZone[Points]['+i+'][y]',
+      'name': 'newZone[Points]['+i+'][y]',
+      'value': zone['Points'][i].y,
+      'size': 5
+    } );
+    input.addEvent('input', updateY.pass(i));
+    input.inject(cell);
+    cell.inject(row);
 
-    cell = new Element( 'td' );
-    new Element( 'a', { 'href': '#', 'events': { 'click': addPoint.pass( i ) } } ).set( 'text', '+' ).inject( cell );
-    if ( zone['Points'].length > 3 )
-      new Element( 'a', { 'id': 'delete'+i, 'href': '#', 'events': { 'click': delPoint.pass( i ) } } ).set( 'text', '-' ).inject( cell );
-    cell.inject( row );
+    cell = new Element('td');
+    new Element('button', {
+      'type': 'button',
+      'events': {'click': addPoint.pass(i)}
+    }).set('text', '+').inject(cell);
+    if ( zone['Points'].length > 3 ) {
+      cell.appendText(' ');
+      new Element('button', {
+        'id': 'delete'+i,
+        'type': 'button',
+        'events': {'click': delPoint.pass(i)}
+      }).set('text', '-').inject(cell);
+    }
+    cell.inject(row);
 
-    row.inject( tables[i%tables.length].getElement( 'tbody' ) );
+    row.inject(tables[i%tables.length].getElement('tbody'));
   }
   // Sets up the SVG polygon
   updateZoneImage();
@@ -431,17 +483,18 @@ var lastAlarmState = STATE_IDLE;
 function setAlarmState( currentAlarmState ) {
   alarmState = currentAlarmState;
 
-  var stateString = "Unknown";
-  var stateClass = "";
-  if ( alarmState == STATE_ALARM )
-    stateClass = "alarm";
-  else if ( alarmState == STATE_ALERT )
-    stateClass = "alert";
-  $('stateValue').set( 'text', stateStrings[alarmState] );
-  if ( stateClass )
-    $('stateValue').setProperty( 'class', stateClass );
-  else
-    $('stateValue').removeProperty( 'class' );
+  var stateClass = '';
+  if ( alarmState == STATE_ALARM ) {
+    stateClass = 'alarm';
+  } else if ( alarmState == STATE_ALERT ) {
+    stateClass = 'alert';
+  }
+  $('stateValue').set('text', stateStrings[alarmState]);
+  if ( stateClass ) {
+    $('stateValue').setProperty('class', stateClass);
+  } else {
+    $('stateValue').removeProperty('class');
+  }
 
   var isAlarmed = ( alarmState == STATE_ALARM || alarmState == STATE_ALERT );
   var wasAlarmed = ( lastAlarmState == STATE_ALARM || lastAlarmState == STATE_ALERT );
@@ -452,27 +505,30 @@ function setAlarmState( currentAlarmState ) {
   if ( newAlarm ) {
     if ( SOUND_ON_ALARM ) {
       // Enable the alarm sound
-      if ( !canPlayPauseAudio )
-        $('alarmSound').removeClass( 'hidden' );
-      else
+      if ( !canPlayPauseAudio ) {
+        $('alarmSound').removeClass('hidden');
+      } else {
         $('MediaPlayer').Play();
+      }
     }
   }
   if ( SOUND_ON_ALARM ) {
     if ( oldAlarm ) {
       // Disable alarm sound
-      if ( !canPlayPauseAudio )
-        $('alarmSound').addClass( 'hidden' );
-      else
+      if ( !canPlayPauseAudio ) {
+        $('alarmSound').addClass('hidden');
+      } else {
         $('MediaPlayer').Stop();
+      }
     }
   }
   lastAlarmState = alarmState;
 }
 
 var streamCmdParms = "view=request&request=stream&connkey="+connKey;
-if ( auth_hash )
-    streamCmdParms += '&auth='+auth_hash;
+if ( auth_hash ) {
+  streamCmdParms += '&auth='+auth_hash;
+}
 var streamCmdReq = new Request.JSON( {
   url: monitorUrl,
   method: 'get',
@@ -484,39 +540,40 @@ var streamCmdTimer = null;
 
 var streamStatus;
 
-function getStreamCmdResponse( respObj, respText ) {
+function getStreamCmdResponse(respObj, respText) {
   watchdogOk("stream");
-  if ( streamCmdTimer )
-    streamCmdTimer = clearTimeout( streamCmdTimer );
+  if ( streamCmdTimer ) {
+    streamCmdTimer = clearTimeout(streamCmdTimer);
+  }
 
   if ( respObj.result == 'Ok' ) {
     streamStatus = respObj.status;
-    $('fpsValue').set( 'text', streamStatus.fps );
+    $('fpsValue').set('text', streamStatus.fps);
 
-    setAlarmState( streamStatus.state );
-
-    var delayString = secsToTime( streamStatus.delay );
+    setAlarmState(streamStatus.state);
 
     if ( streamStatus.paused == true ) {
-      streamCmdPause( false );
+      streamCmdPause(false);
     } else if ( streamStatus.delayed == true && streamStatus.rate == 1 ) {
-      streamCmdPlay( false );
+      streamCmdPlay(false);
     }
   } else {
-    checkStreamForErrors("getStreamCmdResponse", respObj);//log them
+    checkStreamForErrors('getStreamCmdResponse', respObj);//log them
     if ( ! streamPause ) {
       // Try to reload the image stream.
       var streamImg = $('liveStream'+monitorId);
-      if ( streamImg )
-        streamImg.src = streamImg.src.replace(/rand=\d+/i, 'rand='+Math.floor((Math.random() * 1000000) ));
+      if ( streamImg ) {
+        streamImg.src = streamImg.src.replace(/rand=\d+/i, 'rand='+Math.floor(Math.random() * 1000000));
+      }
     }
   }
 
-  if ( ! streamPause ) {
+  if ( !streamPause ) {
     var streamCmdTimeout = statusRefreshTimeout;
-    if ( alarmState == STATE_ALARM || alarmState == STATE_ALERT )
+    if ( alarmState == STATE_ALARM || alarmState == STATE_ALERT ) {
       streamCmdTimeout = streamCmdTimeout/5;
-    streamCmdTimer = streamCmdQuery.delay( streamCmdTimeout );
+    }
+    streamCmdTimer = streamCmdQuery.delay(streamCmdTimeout);
   }
 }
 
@@ -524,38 +581,42 @@ var streamPause = false;
 
 function streamCmdPauseToggle() {
   if ( streamPause == true ) {
-    streamCmdPlay( true );
+    streamCmdPlay(true);
     streamPause = false;
-    document.getElementById("pauseBtn").value = pauseString;
+    document.getElementById('pauseBtn').innerHTML = pauseString;
   } else {
-    streamCmdPause( true );
+    streamCmdPause(true);
     streamPause = true;
-    document.getElementById("pauseBtn").value = playString;
+    document.getElementById('pauseBtn').innerHTML = playString;
   }
 }
 
-function streamCmdPause( action ) {
-  if ( action )
-    streamCmdReq.send( streamCmdParms+"&command="+CMD_PAUSE );
+function streamCmdPause(action) {
+  if ( action ) {
+    streamCmdReq.send(streamCmdParms+"&command="+CMD_PAUSE);
+  }
 }
 
-function streamCmdPlay( action ) {
-  if ( action )
-    streamCmdReq.send( streamCmdParms+"&command="+CMD_PLAY );
+function streamCmdPlay(action) {
+  if ( action ) {
+    streamCmdReq.send(streamCmdParms+"&command="+CMD_PLAY);
+  }
 }
 
-function streamCmdStop( action ) {
-  if ( action )
-    streamCmdReq.send( streamCmdParms+"&command="+CMD_STOP );
+function streamCmdStop(action) {
+  if ( action ) {
+    streamCmdReq.send(streamCmdParms+"&command="+CMD_STOP);
+  }
 }
 
 function streamCmdQuery() {
-  streamCmdReq.send( streamCmdParms+"&command="+CMD_QUERY );
+  streamCmdReq.send(streamCmdParms+"&command="+CMD_QUERY);
 }
 
 var statusCmdParms = "view=request&request=status&entity=monitor&id="+monitorId+"&element[]=Status&element[]=FrameRate";
-if ( auth_hash )
-    statusCmdParms += '&auth='+auth_hash;
+if ( auth_hash ) {
+  statusCmdParms += '&auth='+auth_hash;
+}
 var statusCmdReq = new Request.JSON( {
   url: monitorUrl,
   method: 'get',
@@ -566,22 +627,25 @@ var statusCmdReq = new Request.JSON( {
 } );
 var statusCmdTimer = null;
 
-function getStatusCmdResponse( respObj, respText ) {
+function getStatusCmdResponse(respObj, respText) {
   watchdogOk("status");
-  if ( statusCmdTimer )
-    statusCmdTimer = clearTimeout( statusCmdTimer );
+  if ( statusCmdTimer ) {
+    statusCmdTimer = clearTimeout(statusCmdTimer);
+  }
 
   if ( respObj.result == 'Ok' ) {
-    $('fpsValue').set( 'text', respObj.monitor.FrameRate );
-    setAlarmState( respObj.monitor.Status );
-  } else
+    $('fpsValue').set('text', respObj.monitor.FrameRate);
+    setAlarmState(respObj.monitor.Status);
+  } else {
     checkStreamForErrors("getStatusCmdResponse", respObj);
+  }
 
   if ( ! streamPause ) {
     var statusCmdTimeout = statusRefreshTimeout;
-    if ( alarmState == STATE_ALARM || alarmState == STATE_ALERT )
+    if ( alarmState == STATE_ALARM || alarmState == STATE_ALERT ) {
       statusCmdTimeout = statusCmdTimeout/5;
-    statusCmdTimer = statusCmdQuery.delay( statusCmdTimeout );
+    }
+    statusCmdTimer = statusCmdQuery.delay(statusCmdTimeout);
   }
 }
 
@@ -590,7 +654,7 @@ function statusCmdQuery() {
 }
 
 function fetchImage( streamImage ) {
-  streamImage.src = streamImage.src.replace(/rand=\d+/i,'rand='+Math.floor((Math.random() * 1000000) ));
+  streamImage.src = streamImage.src.replace(/rand=\d+/i, 'rand='+Math.floor((Math.random() * 1000000) ));
 }
 
 function appletRefresh() {
@@ -599,8 +663,9 @@ function appletRefresh() {
     var parent = streamImg.getParent();
     streamImg.dispose();
     streamImg.inject( parent );
-    if ( appletRefreshTime )
+    if ( appletRefreshTime ) {
       appletRefresh.delay( appletRefreshTime*1000 );
+    }
   } else {
     appletRefresh.delay( 15*1000 ); //if we are paused or delayed check every 15 seconds if we are live yet...
   }
@@ -617,9 +682,9 @@ var watchdogFunctions = {
 };
 
 //Make sure the various refreshes are still taking effect
-function watchdogCheck( type ) {
+function watchdogCheck(type) {
   if ( watchdogInactive[type] ) {
-    console.log( "Detected streamWatch of type: " + type + " stopped, restarting" );
+    console.log("Detected streamWatch of type: " + type + " stopped, restarting");
     watchdogFunctions[type]();
     watchdogInactive[type] = false;
   } else {
@@ -627,7 +692,7 @@ function watchdogCheck( type ) {
   }
 }
 
-function watchdogOk( type ) {
+function watchdogOk(type) {
   watchdogInactive[type] = false;
 }
 
@@ -638,18 +703,57 @@ function initPage() {
   //form.elements['newZone[Type]'].disabled = true;
   form.presetSelector.disabled = true;
   //form.elements['newZone[Units]'].disabled = true;
-  form.newAlarmRgbR.disabled = true;
-  form.newAlarmRgbG.disabled = true;
-  form.newAlarmRgbB.disabled = true;
-  form.elements['newZone[CheckMethod]'].disabled = true;
-  form.elements['newZone[MinPixelThreshold]'].disabled = true;
-  form.elements['newZone[MaxPixelThreshold]'].disabled = true;
-  form.elements['newZone[MinAlarmPixels]'].disabled = true;
-  form.elements['newZone[MaxAlarmPixels]'].disabled = true;
-  form.elements['newZone[FilterX]'].disabled = true;
-  form.elements['newZone[FilterY]'].disabled = true;
-  form.elements['newZone[MinFilterPixels]'].disabled = true;
-  form.elements['newZone[MaxFilterPixels]'].disabled = true;
+  if ( CheckMethod = form.elements['newZone[CheckMethod]'] ) {
+    CheckMethod.disabled = true;
+    CheckMethod.onchange = window['applyCheckMethod'].bind(CheckMethod, CheckMethod);
+  }
+
+  [
+    'newZone[MinPixelThreshold]',
+    'newZone[MaxPixelThreshold]',
+    'newAlarmRgbR',
+    'newAlarmRgbG',
+    'newAlarmRgbB',
+  ].forEach(
+      function(element_name, index) {
+        var el = form.elements[element_name];
+        if ( el ) {
+          el.oninput = window['limitRangeToUnsignedByte'].bind(el, el);
+          el.disabled = true;
+        } else {
+          console.error("Element " + element_name + " not found in zone edit form");
+        }
+      });
+  [
+    'newZone[FilterX]',
+    'newZone[FilterY]'
+  ].forEach(
+      function(element_name, index) {
+        var el = form.elements[element_name];
+        if ( el ) {
+          el.oninput = window['limitFilter'].bind(el, el);
+          el.disabled = true;
+        } else {
+          console.error("Element " + element_name + " not found in zone edit form");
+        }
+      }
+  );
+  [
+    'newZone[MinAlarmPixels]',
+    'newZone[MaxAlarmPixels]',
+    'newZone[MinFilterPixels]',
+    'newZone[MaxFilterPixels]'
+  ].forEach(function(element_name, index) {
+    var el = form.elements[element_name];
+    if ( el ) {
+      el.oninput = window['limitArea'].bind(el, el);
+      el.disabled = true;
+    } else {
+      console.error("Element " + element_name + " not found in zone edit form");
+    }
+  }
+  );
+
   form.elements['newZone[MinBlobPixels]'].disabled = true;
   form.elements['newZone[MaxBlobPixels]'].disabled = true;
   form.elements['newZone[MinBlobs]'].disabled = true;
@@ -665,44 +769,61 @@ function initPage() {
   applyCheckMethod();
   drawZonePoints();
 
+  $('pauseBtn').onclick = function() {
+    streamCmdPauseToggle();
+  };
+  if ( el = $('saveBtn') ) {
+    el.onclick = window['saveChanges'].bind(el, el);
+  }
+  if ( el = $('cancelBtn') ) {
+    el.onclick = function() {
+      refreshParentWindow();
+      closeWindow();
+    };
+  }
+
   //
   // Imported from watch.js and modified for new zone edit view
   //
 
-  var delay = (Math.random()+0.1)*statusRefreshTimeout;
+  var delay = (Math.random()+0.1) * statusRefreshTimeout;
   //console.log("Delay for status updates is: " + delay );
-  if ( streamMode == "single" ) {
-    statusCmdTimer = statusCmdQuery.delay( delay );
+  if ( streamMode == 'single' ) {
+    statusCmdTimer = statusCmdQuery.delay(delay);
     watchdogCheck.pass('status').periodical(statusRefreshTimeout*2);
   } else {
-    streamCmdTimer = streamCmdQuery.delay( delay );
+    streamCmdTimer = streamCmdQuery.delay(delay);
     watchdogCheck.pass('stream').periodical(statusRefreshTimeout*2);
   }
 
-  if ( canStreamNative || streamMode == "single" ) {
+  if ( canStreamNative || (streamMode == 'single') ) {
     var streamImg = $('imageFrame').getElement('img');
-    if ( !streamImg )
+    if ( !streamImg ) {
       streamImg = $('imageFrame').getElement('object');
-    if ( streamMode == "single" ) {
-      streamImg.addEvent( 'click', fetchImage.pass( streamImg ) );
-      fetchImage.pass( streamImg ).periodical( imageRefreshTimeout );
+    }
+    if ( streamMode == 'single' ) {
+      streamImg.addEvent('click', fetchImage.pass(streamImg));
+      fetchImage.pass(streamImg).periodical(imageRefreshTimeout);
     }
   }
 
-  if ( refreshApplet && appletRefreshTime )
-    appletRefresh.delay( appletRefreshTime*1000 );
+  if ( refreshApplet && appletRefreshTime ) {
+    appletRefresh.delay(appletRefreshTime*1000);
+  }
 }
 
-function Polygon_calcArea( coords ) {
+function Polygon_calcArea(coords) {
   var n_coords = coords.length;
   var float_area = 0.0;
 
-  for ( i = 0, j = n_coords-1; i < n_coords; j = i++ ) {
-    var trap_area = ( ( coords[i].x - coords[j].x ) * ( coords[i].y + coords[j].y ) ) / 2;
+  for ( i = 0; i < n_coords-1; i++ ) {
+    var trap_area = (coords[i].x*coords[i+1].y - coords[i+1].x*coords[i].y) / 2;
     float_area += trap_area;
     //printf( "%.2f (%.2f)\n", float_area, trap_area );
   }
-  return Math.round( Math.abs( float_area ) );
+  float_area += (coords[n_coords-1].x*coords[0].y - coords[0].x*coords[n_coords-1].y) / 2;
+
+  return Math.round(Math.abs(float_area));
 }
 
-window.addEvent( 'domready', initPage );
+window.addEventListener('DOMContentLoaded', initPage);
